function plot_images(signal_characteristics, thresholds)
% close all
method = 'sobel';

%thresholds for edge detection
t_clean=thresholds.t_clean;
t_noisy=thresholds.t_noisy;
t_recon=thresholds.t_recon;
t_diff=thresholds.t_diff;


%% size of image
M = signal_characteristics.M;
N = signal_characteristics.N;


%% plot images
image_clean = reshape(signal_characteristics.signal_clean,M,N);
% imwrite(image_clean/255,'fig_coins_orig.png')
figure ('Name', 'Image clean')
imagesc(image_clean)
colormap (gray)
axis image
axis off

image_noisy = reshape(signal_characteristics.signal_noisy,M,N);
% imwrite(image_noisy/255,'fig_coins_noisy.png')
figure ('Name', 'Image noisy')
imagesc(image_noisy)
colormap (gray)
axis image
axis off

image_recon = signal_characteristics.signal_recon;
% imwrite(image_recon/255,'fig_coins_recon.png')
figure ('Name', 'Image recon')
imagesc(image_recon)
colormap (gray)
axis image
axis off


%% plot Edges
% obtained differences from coefficients for reconstruction
differences = signal_characteristics.diff;
% compute gradients
image_clean_grad = imgradient(image_clean,method);
image_noisy_grad = imgradient(image_noisy,method);
image_recon_grad = imgradient(image_recon,method);

%take absolute values
image_clean_grad = abs(image_clean_grad);
image_noisy_grad = abs(image_noisy_grad);
image_recon_grad = abs(image_recon_grad);

% maximum
maximum_clean_grad = max(image_clean_grad(:));
maximum_noisy_grad = max(image_noisy_grad(:));
maximum_recon_grad = max(image_recon_grad(:));
maximum_differences = max(differences(:));

% normalization
image_clean_grad_norm=image_clean_grad./maximum_clean_grad;
image_noisy_grad_norm=image_noisy_grad./maximum_noisy_grad;
image_recon_grad_norm=image_recon_grad./maximum_recon_grad;
differences_norm=differences./maximum_differences;

handle_image_clean_grad_norm = figure('Name', 'Image clean norm grad');
imagesc(image_clean_grad_norm)
colorbar
colormap (gray)
axis image
axis off

handle_image_noisy_grad_norm = figure('Name', 'Image noisy norm grad');
imagesc(image_noisy_grad_norm)
colorbar
colormap (gray)
axis image
axis off

handle_image_recon_grad_norm = figure ('Name', 'Image recon norm grad');
imagesc(image_recon_grad_norm)
colorbar
colormap (gray)
axis image
axis off

handle_differences = figure ('Name', 'Differences norm');
imagesc(differences_norm)
colorbar
colormap (gray)
axis image
axis off


%% threshold norm gradient images
image_clean_grad_thresh_norm = false(M,N);
image_clean_grad_thresh_norm(image_clean_grad_norm>t_clean)=true;

image_noisy_grad_thresh_norm = false(M,N);
image_noisy_grad_thresh_norm(image_noisy_grad_norm>t_noisy)=true;

image_recon_grad_thresh_norm = false(M,N);
image_recon_grad_thresh_norm(image_recon_grad_norm>t_recon)=true;

differences_thresh_norm = false (M,N);
differences_thresh_norm(differences_norm>t_diff)=true;


%% plot edge maps
% imwrite(image_clean_grad_thresh_norm,'fig_coins_orig_grad_thresh.png')
figure ('Name', 'Image clean norm grad threshold')
imagesc(image_clean_grad_thresh_norm,[0 1])
colormap (gray)
axis image
axis off

% imwrite(image_noisy_grad_thresh_norm,'fig_coins_noisy_grad_thresh.png')
figure ('Name', 'Image noisy norm grad threshold')
imagesc(image_noisy_grad_thresh_norm,[0 1])
colormap (gray)
axis image
axis off

% imwrite(image_recon_grad_thresh_norm,'fig_coins_recon_grad_thresh.png')
figure ('Name', 'Image recon norm grad threshold')
imagesc(image_recon_grad_thresh_norm,[0 1])
colormap (gray)
axis image
axis off

% imwrite(differences_thresh_norm,'fig_coins_diff_thresh.png')
figure ('Name', 'Differences norm threshold')
imagesc(differences_thresh_norm,[0,1])
colormap (gray)
axis image
axis off


%plot altogether as a subplot array
figure ('Name', (['Norm grad threshold - delta ']))
subplot (2,2,1)
imagesc(image_clean_grad_norm>t_clean,[0 1])
colormap (gray)
axis image
axis off
title (['Image clean norm grad threshold: ', num2str(t_clean)])

subplot(2,2,2)
imagesc(image_noisy_grad_norm>t_noisy,[0 1])
axis image
axis off
title (['Image noisy norm grad threshold: ', num2str(t_noisy)])

subplot(2,2,3)
imagesc(image_recon_grad_norm>t_recon,[0 1])
axis image
axis off
title (['Image recon norm grad threshold: ', num2str(t_recon)])

subplot (2,2,4)
imagesc(differences_norm>t_diff,[0,1])
axis image
axis off
title(['Differences norm threshold: ', num2str(t_diff)])